==> zio-aws-opensearch_2.12-6.20.83.1-sources.jar: zio/aws/opensearch/model/AdditionalLimit.scala <==
package zio.aws.opensearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.opensearch.model.primitives.{LimitValue, LimitName}
import scala.jdk.CollectionConverters._
final case class AdditionalLimit(
    limitName: Optional[LimitName] = Optional.Absent,
    limitValues: Optional[Iterable[LimitValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.AdditionalLimit = {
    import AdditionalLimit.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.AdditionalLimit
      .builder()
      .optionallyWith(
        limitName.map(value => LimitName.unwrap(value): java.lang.String)
      )(_.limitName)
      .optionallyWith(
        limitValues.map(value =>
          value.map { item =>
            LimitValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.limitValues)
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.AdditionalLimit.ReadOnly =
    zio.aws.opensearch.model.AdditionalLimit.wrap(buildAwsValue())
}
object AdditionalLimit {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.AdditionalLimit
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.AdditionalLimit =
      zio.aws.opensearch.model.AdditionalLimit(
        limitName.map(value => value),
        limitValues.map(value => value)
      )
    def limitName: Optional[LimitName]
    def limitValues: Optional[List[LimitValue]]
    def getLimitName: ZIO[Any, AwsError, LimitName] =
      AwsError.unwrapOptionField("limitName", limitName)
    def getLimitValues: ZIO[Any, AwsError, List[LimitValue]] =
      AwsError.unwrapOptionField("limitValues", limitValues)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.AdditionalLimit
  ) extends zio.aws.opensearch.model.AdditionalLimit.ReadOnly {
    override val limitName: Optional[LimitName] = zio.aws.core.internal
      .optionalFromNullable(impl.limitName())
      .map(value => zio.aws.opensearch.model.primitives.LimitName(value))
    override val limitValues: Optional[List[LimitValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.limitValues())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.opensearch.model.primitives.LimitValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.AdditionalLimit
  ): zio.aws.opensearch.model.AdditionalLimit.ReadOnly = new Wrapper(impl)
}

==> zio-aws-opensearch_3-5.17.202.1-sources.jar: zio/aws/opensearch/model/AdditionalLimit.scala <==
package zio.aws.opensearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.opensearch.model.primitives.{LimitValue, LimitName}
import scala.jdk.CollectionConverters.*
final case class AdditionalLimit(
    limitName: Optional[LimitName] = Optional.Absent,
    limitValues: Optional[Iterable[LimitValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.AdditionalLimit = {
    import AdditionalLimit.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.AdditionalLimit
      .builder()
      .optionallyWith(
        limitName.map(value => LimitName.unwrap(value): java.lang.String)
      )(_.limitName)
      .optionallyWith(
        limitValues.map(value =>
          value.map { item =>
            LimitValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.limitValues)
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.AdditionalLimit.ReadOnly =
    zio.aws.opensearch.model.AdditionalLimit.wrap(buildAwsValue())
}
object AdditionalLimit {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.AdditionalLimit
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.AdditionalLimit =
      zio.aws.opensearch.model.AdditionalLimit(
        limitName.map(value => value),
        limitValues.map(value => value)
      )
    def limitName: Optional[LimitName]
    def limitValues: Optional[List[LimitValue]]
    def getLimitName: ZIO[Any, AwsError, LimitName] =
      AwsError.unwrapOptionField("limitName", limitName)
    def getLimitValues: ZIO[Any, AwsError, List[LimitValue]] =
      AwsError.unwrapOptionField("limitValues", limitValues)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.AdditionalLimit
  ) extends zio.aws.opensearch.model.AdditionalLimit.ReadOnly {
    override val limitName: Optional[LimitName] = zio.aws.core.internal
      .optionalFromNullable(impl.limitName())
      .map(value => zio.aws.opensearch.model.primitives.LimitName(value))
    override val limitValues: Optional[List[LimitValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.limitValues())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.opensearch.model.primitives.LimitValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.AdditionalLimit
  ): zio.aws.opensearch.model.AdditionalLimit.ReadOnly = new Wrapper(impl)
}
